@@ -1,5 +1,6 @@
 // Copyright (C) 2016 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
+// Qt-Security score:significant reason:default
 
 #ifndef QTWEBENGINEQUICKGLOBAL_P_H
 #define QTWEBENGINEQUICKGLOBAL_P_H
@@ -19,10 +20,4 @@
 #include <QtCore/private/qglobal_p.h>
 #include <QtWebEngineQuick/private/qtwebenginequick-config_p.h>
 
-QT_BEGIN_NAMESPACE
-
-#define Q_WEBENGINEQUICK_PRIVATE_EXPORT Q_WEBENGINEQUICK_EXPORT
-
-QT_END_NAMESPACE
-
 #endif // QTWEBENGINEQUICKGLOBAL_P_H
